*********************
``matplotlib.colors``
*********************

The Color :ref:`tutorials <tutorials-colors>` and :ref:`examples
<color_examples>` demonstrate how to set colors and colormaps.

.. currentmodule:: matplotlib.colors

.. automodule:: matplotlib.colors
   :no-members:
   :no-inherited-members:

Classes
-------

.. autosummary::
   :toctree: _as_gen/
   :template: autosummary.rst

   BoundaryNorm
   Colormap
   DivergingNorm
   LightSource
   LinearSegmentedColormap
   ListedColormap
   LogNorm
   NoNorm
   Normalize
   PowerNorm
   SymLogNorm
   TwoSlopeNorm

Functions
---------

.. autosummary::
   :toctree: _as_gen/
   :template: autosummary.rst

   from_levels_and_colors
   hsv_to_rgb
   rgb_to_hsv
   to_hex
   to_rgb
   to_rgba
   to_rgba_array
   is_color_like
   same_color
   makeMappingArray
   get_named_colors_mapping
